AdBrixRmCommerceProductModel class

Constructors

AdBrixRmCommerceProductModel({required String productId, required String productName, required double price, required double discount, required int quantity, required AdBrixCurrency currency, required AdBrixRmCommerceCategoryModel category, Map<String, dynamic>? productAttr})

Properties

category ↔ List<String>
getter/setter pair
currency ↔ String
getter/setter pair
discount ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
price ↔ double
getter/setter pair
productAttr ↔ Map<String, dynamic>
getter/setter pair
productId ↔ String
getter/setter pair
productName ↔ String
getter/setter pair
quantity ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProductModel() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProductModel(Map<String, dynamic> setupProduct) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({required String productId, required String productName, required double price, required double discount, required int quantity, required AdBrixCurrency currency, required AdBrixRmCommerceCategoryModel category, Map<String, dynamic>? productAttr}) → AdBrixRmCommerceProductModel